@@ -13,6 +13,7 @@
 #' @param nbSSDoses number of additional doses to use for steady-state (default=10) 
 #' @param obs.rows a list of observation indexes 
 #' @param error.iov TRUE/FALSE (default=TRUE) returns an error message if occasions are overlapping  
+#' @param filter filter to apply to the data (string)  
 #' @param datafile (deprecated) a formatted data file 
 #' @param header (deprecated) a vector of strings  
 #' @param infoProject (deprecated) an xmlfile 
@@ -36,8 +37,8 @@
 #' @importFrom stats time
 #' @importFrom tools file_path_sans_ext
 #' @export
-readDatamlx  <- function(project=NULL, data = NULL, out.data=FALSE, nbSSDoses=10, obs.rows=FALSE,
-                         datafile=NULL, header=NULL, infoProject=NULL, addl.ss=NULL, error.iov=TRUE){
+readDatamlx  <- function(project=NULL, data = NULL, out.data=FALSE, nbSSDoses=10, obs.rows=FALSE, error.iov=FALSE, filter=NULL,
+                         datafile=NULL, header=NULL, infoProject=NULL, addl.ss=NULL){
   id <- NULL
   observationModelName <- NULL
   datas=NULL
@@ -82,7 +83,7 @@ readDatamlx  <- function(project=NULL, data = NULL, out.data=FALSE, nbSSDoses=10
   
   headerList      = c('ID','TIME','AMT','ADM','RATE','TINF','Y','YTYPE',
                       'X','COV','CAT','OCC','MDV','EVID','ADDL','SS','II',
-                      'CENS', 'LIMIT', 'DATE')
+                      'CENS', 'LIMIT', 'DATE', 'IGNOREDLINE')
   newList         = tolower(headerList)
   newList[3:4] <- c('amount','type')
   newHeader       = vector(length=length(header))
@@ -100,7 +101,7 @@ readDatamlx  <- function(project=NULL, data = NULL, out.data=FALSE, nbSSDoses=10
   header[header=="REGRESSOR"]="X"
   nlabel = length(header)
   
-  icov <- icat <- iid <- iamt <- iy <- iytype <- ix <- iocc <- imdv <- NULL
+  icov <- icat <- iid <- iamt <- iy <- iytype <- ix <- iocc <- imdv <- iignoredline <- NULL
   ievid <- iaddl <- iii <- iss <- iadm <- irate <- itinf <- ilimit <- icens <- NULL
   
   for (i in 1:length(headerList)) {
@@ -207,13 +208,23 @@ readDatamlx  <- function(project=NULL, data = NULL, out.data=FALSE, nbSSDoses=10
     )
   }
   
+  if (!is.null(filter))
+    eval(parse(text= paste0("data <- subset(data, ",filter,")")))
+  
   if (out.data) {
     infoProject$delimiter <- delimiter
     infoProject$dataheader <- header
     return(list(data=data, infoProject=infoProject))
   }
   
-  #---remove rows containing NA-------
+  #---remove ignored lines -------
+  if (!is.null(iignoredline)) {
+    il <- which((data[iignoredline])==1)
+    if(length(il)>0)
+      data <- data[-il,]
+  }
+
+  #---remove lines containing NA-------
   if (!is.null(iid)) {
     narowsData <- which(is.na(data[iid])) # removed in ID column only
     if(length(narowsData)>0)
@@ -248,7 +259,7 @@ readDatamlx  <- function(project=NULL, data = NULL, out.data=FALSE, nbSSDoses=10
     if (!is.null(ievid)) {
       levels(S[,ievid])[levels(S[,ievid])=="."] <- "0"  
       S[,ievid] <- as.numeric(as.character(S[,ievid]))
-      iobs1 <- iobs1[S[iobs1,ievid]==0]
+      iobs1 <- iobs1[S[iobs1,ievid] %in% c(0, 2)]
     }
     i0 <- c(grep(' .',S[iobs1,iy],fixed=TRUE),grep('. ',S[iobs1,iy],fixed=TRUE))
     if (length(i0)>0)
@@ -405,7 +416,7 @@ readDatamlx  <- function(project=NULL, data = NULL, out.data=FALSE, nbSSDoses=10
     # u <- u[order(u$id,u$time),]
     
     if ("evid" %in% names(u)){
-      if (any(u$evid==4))
+      if (any(u$evid==4 & error.iov))
         stop("Washout (EVID=4) is not supported", call.=FALSE)
       u$evid <- NULL
     }
@@ -424,7 +435,7 @@ readDatamlx  <- function(project=NULL, data = NULL, out.data=FALSE, nbSSDoses=10
       iobs1 <- iobs1[S[iobs1,imdv[kmdv]]!=1]
   }
   if (!is.null(ievid))
-    iobs1 <- iobs1[S[iobs1,ievid]==0]
+    iobs1 <- iobs1[S[iobs1,ievid] %in% c(0, 2)]
   i0 <- c(grep(' .',S[iobs1,iy],fixed=TRUE),grep('. ',S[iobs1,iy],fixed=TRUE))
   if (length(i0)>0)
     iobs1 <- iobs1[-i0]
@@ -476,7 +487,7 @@ readDatamlx  <- function(project=NULL, data = NULL, out.data=FALSE, nbSSDoses=10
     ix.num <- which(!sapply(Sx,is.numeric))
     if (!is.null(ix.num)) {
       for (k in (ix.num)) {
-        Sx[,ix.num[k]] <- as.numeric(as.character(Sx[,ix.num[k]])) 
+        Sx[,k] <- as.numeric(as.character(Sx[,k])) 
       }
     }
     Dx <- data.frame(id=idnum, time=t, Sx)
